@@ -1706,8 +1706,9 @@ namespace libsemigroups {
       //! \returns
       //! A \c std::string.
       //!
-      //! \throws LibsemigroupsException if the number of generators exceeds
-      //! 49.
+      //! \throws LibsemigroupsException if the ToddCoxeter instance does not
+      //! have kind `twosided`.
+      //! \throws LibsemigroupsException if the number of generators exceeds 49.
       std::string to_gap_string();
 
      private:
@@ -2001,7 +2002,7 @@ namespace libsemigroups {
       }
 
       template <typename TStackDeduct>
-      inline void def_edge(coset_type c, letter_type x, coset_type d) noexcept {
+      void def_edge(coset_type c, letter_type x, coset_type d) noexcept {
         LIBSEMIGROUPS_ASSERT(is_valid_coset(c));
         LIBSEMIGROUPS_ASSERT(x < number_of_generators());
         LIBSEMIGROUPS_ASSERT(is_valid_coset(d));
